@@ -26,7 +26,13 @@ class Data(FrozenClass):
     copy = copy
 
     def __init__(
-        self, symbol="", name="", unit="", symmetries=-1, init_dict=None, init_str=None
+        self,
+        symbol="",
+        name="",
+        unit="",
+        normalizations=-1,
+        init_dict=None,
+        init_str=None,
     ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
@@ -49,14 +55,14 @@ class Data(FrozenClass):
                 name = init_dict["name"]
             if "unit" in list(init_dict.keys()):
                 unit = init_dict["unit"]
-            if "symmetries" in list(init_dict.keys()):
-                symmetries = init_dict["symmetries"]
+            if "normalizations" in list(init_dict.keys()):
+                normalizations = init_dict["normalizations"]
         # Set the properties (value check and convertion are done in setter)
         self.parent = None
         self.symbol = symbol
         self.name = name
         self.unit = unit
-        self.symmetries = symmetries
+        self.normalizations = normalizations
 
         # The class is frozen, for now it's impossible to add new properties
         self._freeze()
@@ -72,7 +78,7 @@ class Data(FrozenClass):
         Data_str += 'symbol = "' + str(self.symbol) + '"' + linesep
         Data_str += 'name = "' + str(self.name) + '"' + linesep
         Data_str += 'unit = "' + str(self.unit) + '"' + linesep
-        Data_str += "symmetries = " + str(self.symmetries) + linesep
+        Data_str += "normalizations = " + str(self.normalizations) + linesep
         return Data_str
 
     def __eq__(self, other):
@@ -86,7 +92,7 @@ class Data(FrozenClass):
             return False
         if other.unit != self.unit:
             return False
-        if other.symmetries != self.symmetries:
+        if other.normalizations != self.normalizations:
             return False
         return True
 
@@ -97,7 +103,9 @@ class Data(FrozenClass):
         Data_dict["symbol"] = self.symbol
         Data_dict["name"] = self.name
         Data_dict["unit"] = self.unit
-        Data_dict["symmetries"] = self.symmetries
+        Data_dict["normalizations"] = (
+            self.normalizations.copy() if self.normalizations is not None else None
+        )
         # The class name is added to the dict for deserialisation purpose
         Data_dict["__class__"] = "Data"
         return Data_dict
@@ -108,7 +116,7 @@ class Data(FrozenClass):
         self.symbol = None
         self.name = None
         self.unit = None
-        self.symmetries = None
+        self.normalizations = None
 
     def _get_symbol(self):
         """getter of symbol"""
@@ -164,21 +172,21 @@ class Data(FrozenClass):
         """,
     )
 
-    def _get_symmetries(self):
-        """getter of symmetries"""
-        return self._symmetries
+    def _get_normalizations(self):
+        """getter of normalizations"""
+        return self._normalizations
 
-    def _set_symmetries(self, value):
-        """setter of symmetries"""
+    def _set_normalizations(self, value):
+        """setter of normalizations"""
         if type(value) is int and value == -1:
             value = dict()
-        check_var("symmetries", value, "dict")
-        self._symmetries = value
+        check_var("normalizations", value, "dict")
+        self._normalizations = value
 
-    symmetries = property(
-        fget=_get_symmetries,
-        fset=_set_symmetries,
-        doc=u"""Dictionary of the symmetries along each axis, used to reduce storage
+    normalizations = property(
+        fget=_get_normalizations,
+        fset=_set_normalizations,
+        doc=u"""Normalizations available for the field and its axes
 
         :Type: dict
         """,
