@@ -109,10 +109,11 @@ class Data1D(Data):
         self,
         values=None,
         is_components=False,
+        symmetries=-1,
         symbol="",
         name="",
         unit="",
-        symmetries=-1,
+        normalizations=-1,
         init_dict=None,
         init_str=None,
     ):
@@ -135,20 +136,23 @@ class Data1D(Data):
                 values = init_dict["values"]
             if "is_components" in list(init_dict.keys()):
                 is_components = init_dict["is_components"]
+            if "symmetries" in list(init_dict.keys()):
+                symmetries = init_dict["symmetries"]
             if "symbol" in list(init_dict.keys()):
                 symbol = init_dict["symbol"]
             if "name" in list(init_dict.keys()):
                 name = init_dict["name"]
             if "unit" in list(init_dict.keys()):
                 unit = init_dict["unit"]
-            if "symmetries" in list(init_dict.keys()):
-                symmetries = init_dict["symmetries"]
+            if "normalizations" in list(init_dict.keys()):
+                normalizations = init_dict["normalizations"]
         # Set the properties (value check and convertion are done in setter)
         self.values = values
         self.is_components = is_components
+        self.symmetries = symmetries
         # Call Data init
         super(Data1D, self).__init__(
-            symbol=symbol, name=name, unit=unit, symmetries=symmetries
+            symbol=symbol, name=name, unit=unit, normalizations=normalizations
         )
         # The class is frozen (in Data init), for now it's impossible to
         # add new properties
@@ -167,6 +171,7 @@ class Data1D(Data):
             + linesep
         )
         Data1D_str += "is_components = " + str(self.is_components) + linesep
+        Data1D_str += "symmetries = " + str(self.symmetries) + linesep
         return Data1D_str
 
     def __eq__(self, other):
@@ -182,6 +187,8 @@ class Data1D(Data):
             return False
         if other.is_components != self.is_components:
             return False
+        if other.symmetries != self.symmetries:
+            return False
         return True
 
     def as_dict(self):
@@ -194,6 +201,9 @@ class Data1D(Data):
         else:
             Data1D_dict["values"] = self.values.tolist()
         Data1D_dict["is_components"] = self.is_components
+        Data1D_dict["symmetries"] = (
+            self.symmetries.copy() if self.symmetries is not None else None
+        )
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         Data1D_dict["__class__"] = "Data1D"
@@ -204,6 +214,7 @@ class Data1D(Data):
 
         self.values = None
         self.is_components = None
+        self.symmetries = None
         # Set to None the properties inherited from Data
         super(Data1D, self)._set_None()
 
@@ -249,3 +260,23 @@ class Data1D(Data):
         :Type: bool
         """,
     )
+
+    def _get_symmetries(self):
+        """getter of symmetries"""
+        return self._symmetries
+
+    def _set_symmetries(self, value):
+        """setter of symmetries"""
+        if type(value) is int and value == -1:
+            value = dict()
+        check_var("symmetries", value, "dict")
+        self._symmetries = value
+
+    symmetries = property(
+        fget=_get_symmetries,
+        fset=_set_symmetries,
+        doc=u"""Dictionary of the symmetries along each axis, used to reduce storage
+
+        :Type: dict
+        """,
+    )
