@@ -5,7 +5,6 @@
 """
 
 from os import linesep
-from logging import getLogger
 from ._check import set_array, check_var, raise_
 from ..Functions.save import save
 from ..Functions.copy import copy
@@ -48,13 +47,12 @@ class DataFreq(DataND):
     def __init__(
         self,
         axes=None,
-        normalizations=-1,
         FTparameters=-1,
         values=None,
         symbol="",
         name="",
         unit="",
-        symmetries=-1,
+        normalizations=-1,
         init_dict=None,
         init_str=None,
     ):
@@ -75,8 +73,6 @@ class DataFreq(DataND):
             # Overwrite default value with init_dict content
             if "axes" in list(init_dict.keys()):
                 axes = init_dict["axes"]
-            if "normalizations" in list(init_dict.keys()):
-                normalizations = init_dict["normalizations"]
             if "FTparameters" in list(init_dict.keys()):
                 FTparameters = init_dict["FTparameters"]
             if "values" in list(init_dict.keys()):
@@ -87,19 +83,18 @@ class DataFreq(DataND):
                 name = init_dict["name"]
             if "unit" in list(init_dict.keys()):
                 unit = init_dict["unit"]
-            if "symmetries" in list(init_dict.keys()):
-                symmetries = init_dict["symmetries"]
+            if "normalizations" in list(init_dict.keys()):
+                normalizations = init_dict["normalizations"]
         # Set the properties (value check and convertion are done in setter)
         # Call DataND init
         super(DataFreq, self).__init__(
             axes=axes,
-            normalizations=normalizations,
             FTparameters=FTparameters,
             values=values,
             symbol=symbol,
             name=name,
             unit=unit,
-            symmetries=symmetries,
+            normalizations=normalizations,
         )
         # The class is frozen (in DataND init), for now it's impossible to
         # add new properties
