@@ -119,10 +119,11 @@ class DataLinspace(Data):
         number=None,
         include_endpoint=True,
         is_components=False,
+        symmetries=-1,
         symbol="",
         name="",
         unit="",
-        symmetries=-1,
+        normalizations=-1,
         init_dict=None,
         init_str=None,
     ):
@@ -153,14 +154,16 @@ class DataLinspace(Data):
                 include_endpoint = init_dict["include_endpoint"]
             if "is_components" in list(init_dict.keys()):
                 is_components = init_dict["is_components"]
+            if "symmetries" in list(init_dict.keys()):
+                symmetries = init_dict["symmetries"]
             if "symbol" in list(init_dict.keys()):
                 symbol = init_dict["symbol"]
             if "name" in list(init_dict.keys()):
                 name = init_dict["name"]
             if "unit" in list(init_dict.keys()):
                 unit = init_dict["unit"]
-            if "symmetries" in list(init_dict.keys()):
-                symmetries = init_dict["symmetries"]
+            if "normalizations" in list(init_dict.keys()):
+                normalizations = init_dict["normalizations"]
         # Set the properties (value check and convertion are done in setter)
         self.initial = initial
         self.final = final
@@ -168,9 +171,10 @@ class DataLinspace(Data):
         self.number = number
         self.include_endpoint = include_endpoint
         self.is_components = is_components
+        self.symmetries = symmetries
         # Call Data init
         super(DataLinspace, self).__init__(
-            symbol=symbol, name=name, unit=unit, symmetries=symmetries
+            symbol=symbol, name=name, unit=unit, normalizations=normalizations
         )
         # The class is frozen (in Data init), for now it's impossible to
         # add new properties
@@ -187,6 +191,7 @@ class DataLinspace(Data):
         DataLinspace_str += "number = " + str(self.number) + linesep
         DataLinspace_str += "include_endpoint = " + str(self.include_endpoint) + linesep
         DataLinspace_str += "is_components = " + str(self.is_components) + linesep
+        DataLinspace_str += "symmetries = " + str(self.symmetries) + linesep
         return DataLinspace_str
 
     def __eq__(self, other):
@@ -210,6 +215,8 @@ class DataLinspace(Data):
             return False
         if other.is_components != self.is_components:
             return False
+        if other.symmetries != self.symmetries:
+            return False
         return True
 
     def as_dict(self):
@@ -223,6 +230,9 @@ class DataLinspace(Data):
         DataLinspace_dict["number"] = self.number
         DataLinspace_dict["include_endpoint"] = self.include_endpoint
         DataLinspace_dict["is_components"] = self.is_components
+        DataLinspace_dict["symmetries"] = (
+            self.symmetries.copy() if self.symmetries is not None else None
+        )
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         DataLinspace_dict["__class__"] = "DataLinspace"
@@ -237,6 +247,7 @@ class DataLinspace(Data):
         self.number = None
         self.include_endpoint = None
         self.is_components = None
+        self.symmetries = None
         # Set to None the properties inherited from Data
         super(DataLinspace, self)._set_None()
 
@@ -347,3 +358,23 @@ class DataLinspace(Data):
         :Type: bool
         """,
     )
+
+    def _get_symmetries(self):
+        """getter of symmetries"""
+        return self._symmetries
+
+    def _set_symmetries(self, value):
+        """setter of symmetries"""
+        if type(value) is int and value == -1:
+            value = dict()
+        check_var("symmetries", value, "dict")
+        self._symmetries = value
+
+    symmetries = property(
+        fget=_get_symmetries,
+        fset=_set_symmetries,
+        doc=u"""Dictionary of the symmetries along each axis, used to reduce storage
+
+        :Type: dict
+        """,
+    )
