@@ -324,13 +324,12 @@ class DataND(Data):
     def __init__(
         self,
         axes=None,
-        normalizations=-1,
         FTparameters=-1,
         values=None,
         symbol="",
         name="",
         unit="",
-        symmetries=-1,
+        normalizations=-1,
         init_dict=None,
         init_str=None,
     ):
@@ -351,8 +350,6 @@ class DataND(Data):
             # Overwrite default value with init_dict content
             if "axes" in list(init_dict.keys()):
                 axes = init_dict["axes"]
-            if "normalizations" in list(init_dict.keys()):
-                normalizations = init_dict["normalizations"]
             if "FTparameters" in list(init_dict.keys()):
                 FTparameters = init_dict["FTparameters"]
             if "values" in list(init_dict.keys()):
@@ -363,16 +360,15 @@ class DataND(Data):
                 name = init_dict["name"]
             if "unit" in list(init_dict.keys()):
                 unit = init_dict["unit"]
-            if "symmetries" in list(init_dict.keys()):
-                symmetries = init_dict["symmetries"]
+            if "normalizations" in list(init_dict.keys()):
+                normalizations = init_dict["normalizations"]
         # Set the properties (value check and convertion are done in setter)
         self.axes = axes
-        self.normalizations = normalizations
         self.FTparameters = FTparameters
         self.values = values
         # Call Data init
         super(DataND, self).__init__(
-            symbol=symbol, name=name, unit=unit, symmetries=symmetries
+            symbol=symbol, name=name, unit=unit, normalizations=normalizations
         )
         # The class is frozen (in Data init), for now it's impossible to
         # add new properties
@@ -384,7 +380,6 @@ class DataND(Data):
         # Get the properties inherited from Data
         DataND_str += super(DataND, self).__str__()
         DataND_str += "axes = " + str(self.axes) + linesep + linesep
-        DataND_str += "normalizations = " + str(self.normalizations) + linesep
         DataND_str += "FTparameters = " + str(self.FTparameters) + linesep
         DataND_str += (
             "values = "
@@ -406,8 +401,6 @@ class DataND(Data):
             return False
         if other.axes != self.axes:
             return False
-        if other.normalizations != self.normalizations:
-            return False
         if other.FTparameters != self.FTparameters:
             return False
         if not array_equal(other.values, self.values):
@@ -425,8 +418,9 @@ class DataND(Data):
             DataND_dict["axes"] = list()
             for obj in self.axes:
                 DataND_dict["axes"].append(obj.as_dict())
-        DataND_dict["normalizations"] = self.normalizations
-        DataND_dict["FTparameters"] = self.FTparameters
+        DataND_dict["FTparameters"] = (
+            self.FTparameters.copy() if self.FTparameters is not None else None
+        )
         if self.values is None:
             DataND_dict["values"] = None
         else:
@@ -440,7 +434,6 @@ class DataND(Data):
         """Set all the properties to None (except SciDataTool object)"""
 
         self.axes = None
-        self.normalizations = None
         self.FTparameters = None
         self.values = None
         # Set to None the properties inherited from Data
@@ -477,26 +470,6 @@ class DataND(Data):
         """,
     )
 
-    def _get_normalizations(self):
-        """getter of normalizations"""
-        return self._normalizations
-
-    def _set_normalizations(self, value):
-        """setter of normalizations"""
-        if type(value) is int and value == -1:
-            value = dict()
-        check_var("normalizations", value, "dict")
-        self._normalizations = value
-
-    normalizations = property(
-        fget=_get_normalizations,
-        fset=_set_normalizations,
-        doc=u"""Normalizations available for the field and its axes
-
-        :Type: dict
-        """,
-    )
-
     def _get_FTparameters(self):
         """getter of FTparameters"""
         return self._FTparameters
