@@ -1,21 +1,13 @@
 # -*- coding: utf-8 -*-
-from numpy import prod, mean, hanning, linspace, argmin, abs, where, isclose
-from numpy.fft import fft, rfftn, ifftn, fftn, fftshift, rfft2
-from scipy.fftpack import ifft, ifftshift
+from numpy import mean, hanning, linspace, where, isclose, apply_along_axis
+from numpy.fft import fft, fftshift, ifft, ifftshift
 from numpy import (
     pi,
     zeros,
-    cos,
     exp,
-    log,
-    meshgrid,
-    array,
     abs as np_abs,
     angle as np_angle,
 )
-from numpy import linalg, transpose, dot
-from scipy.signal import stft, spectrogram
-import matplotlib.pyplot as plt
 
 
 def comp_fft_freqs(time, is_time, is_positive):
@@ -64,12 +56,16 @@ def comp_fft_time(freqs, is_angle):
         time = [0]
     else:
         N_tot = len(freqs)  # Number of samples
-        fsampt = freqs[-1] * 2.0
-        timestep = 1.0 / fsampt
+        fs = freqs[-1] / (N_tot - 1)
+        tf = 1 / (fs * 2)
+        time = linspace(0, tf, N_tot, endpoint=False)
+        # fsampt = freqs[-1] * 2.0
+        # timestep = 1.0 / fsampt
         if is_angle:
-            timestep *= 2.0 * pi
-        time = [0 + i * timestep for i in range(N_tot)]
-    return time
+            time *= 2.0 * pi
+            # timestep *= 2.0 * pi
+        # time = [0 + i * timestep for i in range(N_tot)]
+    return time.tolist()
 
 
 def comp_nthoctave_axis(noct, freqmin, freqmax):
@@ -140,7 +136,7 @@ def comp_nthoctave_axis(noct, freqmin, freqmax):
     return f_oct
 
 
-def comp_fft(values, axes=None):
+def _comp_fft(values, n=0):
     """Computes the Fourier Transform
     Parameters
     ----------
@@ -150,45 +146,71 @@ def comp_fft(values, axes=None):
     -------
     Complex Fourier Transform
     """
-    values_shape = values.shape
-    values_FT = fftn(values)
-    values_FT[tuple([0 for N in values_shape])] *= 0.5
-    values_FT = 2.0 * fftshift(values_FT) / float(prod([N for N in values_shape]))
+    values_FT = fft(values)
+    if n == 0:
+        values_FT[0] *= 0.5
+        values_FT = 2.0 * fftshift(values_FT) / len(values)
+    else:
+        values_FT = fftshift(values_FT) / len(values)
     return values_FT
 
 
-def comp_ifft(values):
-    """Computes the inverse Fourier Transform
-    Parameters
-    ----------
-    values: ndarray
-        complex Fourier transform
-    Returns
-    -------
-    ndarray of the field
-    """
-
-    values_shape = values.shape
-    values[tuple([N // 2 for N in values_shape])] *= 2
-    values = ifftshift(values * float(prod([N for N in values_shape])) / 2)
-    values = ifftn(values)
-    return values.real
-
-
-def comp_rfft(values):
-    """Computes the Fourier Transform restricted to positive freqs
+def comp_fftn(values, axes_list):
+    """Computes the Fourier Transform
     Parameters
     ----------
     values: ndarray
         ndarray of the field
     Returns
     -------
-    Complex Fourier Transform restricted to positive freqs
+    Complex Fourier Transform
     """
-    values_shape = values.shape
-    values_FT = rfft2(values)
-    values_FT = values_FT / float(prod(values_shape))
-    return values_FT
+
+    n = 0
+    for axis in axes_list:
+        if axis.transform == "fft":
+            values = apply_along_axis(_comp_fft, axis.index, values, n=n)
+            n = n + 1
+    return values
+
+
+def _comp_ifft(values, n=0):
+    """Computes the Inverse Fourier Transform
+    Parameters
+    ----------
+    values: ndarray
+        ndarray of the FT
+    Returns
+    -------
+    IFT
+    """
+
+    if n == 0:
+        values[0] *= 2
+        values = ifftshift(values * len(values) / 2)
+    else:
+        values = ifftshift(values) * len(values)
+    values_IFT = ifft(values)
+    return values_IFT
+
+
+def comp_ifftn(values, axes_list):
+    """Computes the Inverse Fourier Transform
+    Parameters
+    ----------
+    values: ndarray
+        ndarray of the FT
+    Returns
+    -------
+    IFT
+    """
+
+    n = 0
+    for axis in axes_list:
+        if axis.transform == "ifft":
+            values = apply_along_axis(_comp_ifft, axis.index, values, n=n)
+            n = n + 1
+    return values
 
 
 def comp_magnitude(values):
@@ -201,7 +223,7 @@ def comp_magnitude(values):
     -------
     Magnitude of the Fourier Transform
     """
-    return np_abs(comp_fft(values))
+    return np_abs(_comp_fft(values))
 
 
 #    return np_abs(comp_stft_average(values))
@@ -215,7 +237,7 @@ def comp_phase(values):
     -------
     Phase of the Fourier Transform
     """
-    return np_angle(comp_fft(values))
+    return np_angle(_comp_fft(values))
 
 
 def comp_stft_average(values):
@@ -259,7 +281,9 @@ def comp_fft_average(values):
     nwindows = int(N_tot / (2.0 * step))
     values_fft = zeros(nperseg, dtype="complex128")
     for i in range(nwindows):
-        values_fft += comp_fft(values[i * step : nperseg + i * step] * hanning(nperseg))
+        values_fft += _comp_fft(
+            values[i * step : nperseg + i * step] * hanning(nperseg)
+        )
     values = values_fft[int(nperseg / 2) :] / nwindows
     f = linspace(0, int(N_tot / 2), int(nperseg / 2))
     return f, np_abs(values)
