@@ -29,40 +29,36 @@ def get_common_base(values1, values2, is_extrap=False, is_downsample=False):
     -------
     list of the common axis values
     """
-    if len(values1) == 2:
-        return array([x for x in values2 if x >= values1[0] and x <= values1[-1]])
+    # if len(values1) == 2:
+    #     return array([x for x in values2 if x >= values1[0] and x <= values1[-1]])
+    # else:
+    if is_extrap:
+        initial = min(values1[0], values2[0])
+        final = max(values1[-1], values2[-1])
     else:
-        if is_extrap:
-            initial = min(values1[0], values2[0])
-            final = max(values1[-1], values2[-1])
+        initial = max(values1[0], values2[0])
+        final = min(values1[-1], values2[-1])
+    if is_downsample:
+        number = min(
+            len([i for i in values1 if i >= initial and i <= final]),
+            len([i for i in values2 if i >= initial and i <= final]),
+        )
+    else:
+        length1 = len([i for i in values1 if i >= initial and i <= final])
+        length2 = len([i for i in values2 if i >= initial and i <= final])
+        if length1 > length2:
+            number = length1
+            if initial not in values1:
+                initial = values1[argmin(np_abs([i - initial for i in values1])) + 1]
+            if final not in values1:
+                final = values1[argmin(np_abs([i - final for i in values1])) - 1]
         else:
-            initial = max(values1[0], values2[0])
-            final = min(values1[-1], values2[-1])
-        if is_downsample:
-            number = min(
-                len([i for i in values1 if i >= initial and i <= final]),
-                len([i for i in values2 if i >= initial and i <= final]),
-            )
-        else:
-            length1 = len([i for i in values1 if i >= initial and i <= final])
-            length2 = len([i for i in values2 if i >= initial and i <= final])
-            if length1 > length2:
-                number = length1
-                if initial not in values1:
-                    initial = values1[
-                        argmin(np_abs([i - initial for i in values1])) + 1
-                    ]
-                if final not in values1:
-                    final = values1[argmin(np_abs([i - final for i in values1])) - 1]
-            else:
-                number = length2
-                if initial not in values2:
-                    initial = values2[
-                        argmin(np_abs([i - initial for i in values2])) + 1
-                    ]
-                if final not in values2:
-                    final = values2[argmin(np_abs([i - final for i in values2])) - 1]
-        return linspace(initial, final, int(number), endpoint=True)
+            number = length2
+            if initial not in values2:
+                initial = values2[argmin(np_abs([i - initial for i in values2])) + 1]
+            if final not in values2:
+                final = values2[argmin(np_abs([i - final for i in values2])) - 1]
+    return linspace(initial, final, int(number), endpoint=True)
 
 
 def get_interpolation(values, axis_values, new_axis_values):
