@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from numpy import pi, sqrt  # for eval
+from numpy import pi, sqrt, inf  # for eval
 from SciDataTool.Functions import AxisError
 from SciDataTool.Classes.RequestedAxis import RequestedAxis
 
@@ -27,6 +27,17 @@ def read_input_strings(args, axis_data):
             elems = axis_str.split("{")
             unit = elems[1].strip("}")
             axis_str = elems[0]
+        # Detect normalization
+        if "->" in axis_str:
+            elems = axis_str.split("->")
+            if "=" in axis_str:
+                unit = elems[1].split("=")[0]
+            elif "[" in axis_str:
+                unit = elems[1].split("[")[0]
+            else:
+                unit = elems[1]
+            name = elems[0]
+            axis_str = axis_str.replace("->" + unit, "")
         # Detect sum
         if "sum" in axis_str:
             elems = axis_str.split("=sum")
@@ -48,14 +59,29 @@ def read_input_strings(args, axis_data):
         elif "axis_data" in axis_str:
             elems = axis_str.split("=axis_data")
             name = elems[0]
-            extension = "interval"
+            extension = "axis_data"
             try:
-                input_data = axis_data[int(elems[1]) - 1]
+                input_data = axis_data[name]
             except:
-                try:
-                    input_data = axis_data[0]
-                except:
-                    raise AxisError("ERROR: Absence of axis_data")
+                raise AxisError("ERROR: No axis_data provided")
+        # Detect above
+        elif ">" in axis_str:
+            elems = axis_str.split(">")
+            init_str = elems[1]
+            interval_init = eval(init_str)
+            interval_final = inf
+            name = elems[0]
+            extension = "interval"
+            input_data = [interval_init, interval_final]
+        # Detect below
+        elif "<" in axis_str:
+            elems = axis_str.split("<")
+            init_str = elems[1]
+            interval_init = -inf
+            interval_final = eval(init_str)
+            name = elems[0]
+            extension = "interval"
+            input_data = [interval_init, interval_final]
         # Detect interval
         elif "=[" in axis_str:
             elems = axis_str.split("=[")
@@ -86,7 +112,7 @@ def read_input_strings(args, axis_data):
             # List of indices
             elif "," in ind_str:
                 extension = "list"
-                indices = ind_str.split(",")
+                indices = [int(x) for x in ind_str.split(",")]
             # Single index
             else:
                 extension = "single"
