@@ -6,7 +6,7 @@ from numpy import array
 from importlib import import_module
 
 
-def get_axis(self, axis, normalizations):
+def get_axis(self, axis):
     """Computes the vector 'axis' in the unit required, using conversions and symmetries if needed.
     Parameters
     ----------
@@ -14,12 +14,16 @@ def get_axis(self, axis, normalizations):
         a RequestedAxis object
     axis: Axis
         an Axis object
-    normalizations: dict
-        dictionary of the normalizations
     """
     is_components = getattr(axis, "is_components", False)
     if is_components:
-        self.values = None
+        values = axis.get_values()
+        if self.extension != "sum":
+            self.extension = "list"
+        if self.indices is not None:
+            self.values = values[self.indices]
+        else:
+            self.values = values
     else:
         if self.extension == "smallestperiod":
             is_smallestperiod = True
@@ -33,6 +37,10 @@ def get_axis(self, axis, normalizations):
             is_smallestperiod = False
             is_oneperiod = True
             is_antiperiod = False
+        elif self.extension == "axis_data":
+            is_smallestperiod = True
+            is_oneperiod = False
+            is_antiperiod = False
         else:
             is_smallestperiod = False
             is_oneperiod = False
@@ -62,25 +70,23 @@ def get_axis(self, axis, normalizations):
         unit = self.unit
         if unit == self.corr_unit or unit == "SI":
             pass
-        elif unit in normalizations:
-            values = array([v / normalizations.get(unit) for v in values])
+        elif unit in axis.normalizations:
+            values = array([v / axis.normalizations.get(unit) for v in values])
         else:
             values = convert(values, self.corr_unit, unit)
         # Rebuild symmetries in fft case
-        if self.transform == "fft" and axis.name in axis.symmetries:
-            if "period" in axis.symmetries.get(axis.name).keys():
+        if self.transform == "fft":
+            if "period" in axis.symmetries:
                 if axis.name != "time":
-                    values = values * axis.symmetries.get(axis.name).get("period")
-            elif "antiperiod" in axis.symmetries.keys() and axis.name != "time":
+                    values = values * axis.symmetries["period"]
+            elif "antiperiod" in axis.symmetries:
                 if axis.name != "time":
-                    values = (
-                        values * axis.symmetries.get(axis.name).get("antiperiod") / 2
-                    )
+                    values = values * axis.symmetries["antiperiod"] / 2
         # Interpolate axis with input data
         if self.extension in ["whole", "oneperiod", "antiperiod", "smallestperiod"]:
             self.values = values
         elif self.input_data is not None:
-            if len(self.input_data) == 2:
+            if len(self.input_data) == 2 and self.extension != "axis_data":
                 self.indices = [
                     i
                     for i, x in enumerate(values)
@@ -88,7 +94,12 @@ def get_axis(self, axis, normalizations):
                 ]
                 self.input_data = None
             else:
-                self.input_data = get_common_base(self.input_data, values)
+                if self.extension == "axis_data":
+                    self.input_data = get_common_base(
+                        self.input_data, values, is_downsample=True
+                    )
+                else:
+                    self.input_data = get_common_base(self.input_data, values)
                 self.values = values
         if self.indices is not None:
             self.values = values[self.indices]
