@@ -28,36 +28,36 @@ def get_rphiz_along(self, *args, unit="SI", is_norm=False, axis_data=[]):
     if len(args) == 1 and type(args[0]) == tuple:
         args = args[0]  # if called from another script with *args
 
-    if "x" in self.components.keys() and "y" in self.components.keys():
+    if "comp_x" in self.components.keys() and "comp_y" in self.components.keys():
         # Extract from DataND
-        resultx = self.components["x"].get_along(
+        resultx = self.components["comp_x"].get_along(
             args, unit=unit, is_norm=is_norm, axis_data=axis_data
         )
-        resulty = self.components["y"].get_along(
+        resulty = self.components["comp_y"].get_along(
             args, unit=unit, is_norm=is_norm, axis_data=axis_data
         )
-        field_x = resultx[self.components["x"].symbol]
-        field_y = resulty[self.components["y"].symbol]
+        field_x = resultx[self.components["comp_x"].symbol]
+        field_y = resulty[self.components["comp_y"].symbol]
         shape = field_x.shape
         x = resultx["x"]
         y = resultx["y"]
         # Convert to cylindrical coordinates
         (r, phi) = xy_to_rphi(x, y)
-        (field_r, field_t) = cart2pol(field_x, field_y, phi)
+        (field_r, field_c) = cart2pol(field_x, field_y, phi)
         if "axial" in self.components.keys():
             resultz = self.components["axial"].get_along(
                 args, unit=unit, is_norm=is_norm, axis_data=axis_data
             )
             field_z = resultz[self.components["axial"].symbol]
-        elif "z" in self.components.keys():
-            resultz = self.components["z"].get_along(
+        elif "comp_z" in self.components.keys():
+            resultz = self.components["comp_z"].get_along(
                 args, unit=unit, is_norm=is_norm, axis_data=axis_data
             )
-            field_z = resultz[self.components["z"].symbol]
+            field_z = resultz[self.components["comp_z"].symbol]
         else:
             field_z = zeros(shape)
         return_dict = dict(resultx)
-        del return_dict[self.components["x"].symbol]
+        del return_dict[self.components["comp_x"].symbol]
 
     elif "radial" in self.components.keys():
         resultr = self.components["radial"].get_along(
@@ -69,30 +69,30 @@ def get_rphiz_along(self, *args, unit="SI", is_norm=False, axis_data=[]):
             resultphi = self.components["tangential"].get_along(
                 args, unit=unit, is_norm=is_norm, axis_data=axis_data
             )
-            field_t = resultphi[self.components["tangential"].symbol]
+            field_c = resultphi[self.components["tangential"].symbol]
         else:
-            field_t = zeros(shape)
+            field_c = zeros(shape)
         if "axial" in self.components.keys():
             resultz = self.components["axial"].get_along(
                 args, unit=unit, is_norm=is_norm, axis_data=axis_data
             )
             field_z = resultz[self.components["axial"].symbol]
-        elif "z" in self.components.keys():
-            resultz = self.components["z"].get_along(
+        elif "comp_z" in self.components.keys():
+            resultz = self.components["comp_z"].get_along(
                 args, unit=unit, is_norm=is_norm, axis_data=axis_data
             )
-            field_z = resultz[self.components["z"].symbol]
+            field_z = resultz[self.components["comp_z"].symbol]
         else:
             field_z = zeros(shape)
         return_dict = dict(resultr)
         del return_dict[self.components["radial"].symbol]
 
     elif "tangential" in self.components.keys():
-        resultphi = self.components["tangential"].get_along(
+        resultphi = self.components["circumferential"].get_along(
             args, unit=unit, is_norm=is_norm, axis_data=axis_data
         )
-        field_t = resultphi[self.components["tangential"].symbol]
-        shape = field_t.shape
+        field_c = resultphi[self.components["tangential"].symbol]
+        shape = field_c.shape
         if "radial" in self.components.keys():
             resultr = self.components["radial"].get_along(
                 args, unit=unit, is_norm=is_norm, axis_data=axis_data
@@ -105,11 +105,11 @@ def get_rphiz_along(self, *args, unit="SI", is_norm=False, axis_data=[]):
                 args, unit=unit, is_norm=is_norm, axis_data=axis_data
             )
             field_z = resultz[self.components["axial"].symbol]
-        elif "z" in self.components.keys():
-            resultz = self.components["z"].get_along(
+        elif "comp_z" in self.components.keys():
+            resultz = self.components["comp_z"].get_along(
                 args, unit=unit, is_norm=is_norm, axis_data=axis_data
             )
-            field_z = resultz[self.components["z"].symbol]
+            field_z = resultz[self.components["comp_z"].symbol]
         else:
             field_z = zeros(shape)
         return_dict = dict(resultphi)
@@ -122,28 +122,28 @@ def get_rphiz_along(self, *args, unit="SI", is_norm=False, axis_data=[]):
         field_z = resultz[self.components["axial"].symbol]
         shape = field_z.shape
         field_r = zeros(shape)
-        field_t = zeros(shape)
+        field_c = zeros(shape)
         return_dict = dict(resultz)
         del return_dict[self.components["axial"].symbol]
 
-    elif "z" in self.components.keys():
-        resultz = self.components["z"].get_along(
+    elif "comp_z" in self.components.keys():
+        resultz = self.components["comp_z"].get_along(
             args, unit=unit, is_norm=is_norm, axis_data=axis_data
         )
-        field_z = resultz[self.components["z"].symbol]
+        field_z = resultz[self.components["comp_z"].symbol]
         shape = field_z.shape
         field_r = zeros(shape)
-        field_t = zeros(shape)
+        field_c = zeros(shape)
         return_dict = resultz
-        del return_dict[self.components["z"].symbol]
+        del return_dict[self.components["comp_z"].symbol]
 
     else:
         raise AxisError(
-            "Vector_field object is empty (should contain at least radial, tangential, axial, x, y or z"
+            "Vector_field object is empty (should contain at least radial, circumferential, axial, x, y or z"
         )
 
     return_dict["radial"] = field_r
-    return_dict["tangential"] = field_t
+    return_dict["tangential"] = field_c
     return_dict["axial"] = field_z
 
     return return_dict
